##
##  xz.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 5.6.1
%define       V_dist 5.6.1

#   package information
Name:         xz
Summary:      Lempel-Ziv-Markov Algorithm (LZMA) Compression
URL:          http://xz.tukaani.org/xz-utils/
Vendor:       Igor Pavlov, Lasse Collin
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Compression
License:      PD/GPL
Version:      %{V_opkg}
Release:      20240310

#   list of sources
Source0:      https://github.com/tukaani-project/xz/releases/download/v%{V_dist}/xz-%{V_dist}.tar.gz
Patch0:       xz.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Command line implementation of LZMA compression algorithm. This tool
    uses the XZ file format (as opposed to the 7z container format),
    which uses LZMA as the default compression algorithm, but has many
    additional features and a header incompatible to that of raw LZMA
    streams. Compression ratio of LZMA is about 25-30% better than
    bzip2(1) and decompression speed is about two times faster. The
    downside is higher CPU and RAM requirements for compression.

%track
    prog xz = {
        version   = %{V_dist}
        url       = https://xz.tukaani.org/xz-utils/
        regex     = xz-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n xz-%{V_dist}
    %patch -p0

%build
    (  echo "ac_cv_func_CC_SHA256_Init=no"
       echo "ac_cv_func_SHA256_Init=no"
       echo "ac_cv_func_SHA256Init=no"
       echo "ac_cv_type_CC_SHA256_CTX=no"
       echo "ac_cv_type_SHA256_CTX=no"
       echo "ac_cv_type_SHA2_CTX=no"
    ) >config.cache
    opts=""
    case "%{l_platform -p}" in
        *-macosx* ) opts="--disable-assembler" ;;
    esac
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --without-libiconv-prefix \
        --without-libintl-prefix \
        --disable-nls \
        --disable-shared \
        $opts
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

